<xsl:stylesheet version='1.0' xmlns:xsl='http://www.w3.org/1999/XSL/Transform'>

  <!-- Main Generator Loop -->
  <xsl:template match="project">
    <xsl:call-template name="begin_body"/>
    
    <xsl:text>&lt;h1&gt;Meetings&lt;/h1&gt;</xsl:text>
    <xsl:call-template name="newline"/>
    <xsl:for-each select="meetings/meeting">
      <xsl:text>&lt;h2&gt;Meeting held on </xsl:text><xsl:value-of select="@date"/><xsl:text>&lt;/h2&gt;</xsl:text>
      <xsl:call-template name="newline"/>

      <xsl:for-each select="present">
        <xsl:text>&lt;b&gt;Present:&lt;/b&gt; </xsl:text><xsl:value-of select="@name"/>
        <xsl:call-template name="newline"/>
      </xsl:for-each>

      <xsl:for-each select="absent">
        <xsl:text>&lt;b&gt;Absent:&lt;/b&gt; </xsl:text><xsl:value-of select="@name"/>
        <xsl:call-template name="newline"/>
      </xsl:for-each>

      <xsl:for-each select="item">
        <xsl:call-template name="newline"/>
        <xsl:text>&lt;b&gt;Discussion point:&lt;/b&gt; </xsl:text>
<!--        <xsl:call-template name="newline"/> -->
        <xsl:value-of select="description"/>
        <xsl:call-template name="newline"/>
        <xsl:text>&lt;b&gt;Actions required:&lt;/b&gt; </xsl:text>
<!--        <xsl:call-template name="newline"/> -->
        <xsl:value-of select="action"/>
        <xsl:call-template name="newline"/>
        <xsl:text>&lt;b&gt;Responsibility:&lt;/b&gt; </xsl:text><xsl:value-of select="@owner"/>
<!--        <xsl:call-template name="newline"/> -->
        <xsl:text> &lt;b&gt;Due by:&lt;/b&gt; </xsl:text><xsl:value-of select="@due"/>
        <xsl:call-template name="newline"/>
      </xsl:for-each>
    </xsl:for-each>


    <xsl:text>&lt;h1&gt;Requirements&lt;/h1&gt;</xsl:text>
    <xsl:call-template name="newline"/>
    <xsl:for-each select="requirements/requirement">
      <xsl:text>&lt;h2&gt;REQ-</xsl:text><xsl:value-of select="@number"/><xsl:text>: </xsl:text><xsl:value-of select="@heading"/><xsl:text>&lt;/h2&gt;</xsl:text>
      <xsl:call-template name="newline"/>
      <xsl:value-of select="description"/>
      <xsl:call-template name="newline"/>
      <xsl:text>&lt;b&gt;The following source code implements this requirement:&lt;/b&gt;</xsl:text>
      <xsl:call-template name="newline"/>
      &lt;ul&gt;
      <xsl:for-each select="code">
          &lt;li&gt;
            <xsl:text>&lt;a href="file://</xsl:text><xsl:value-of select="@filename"/><xsl:text>"&gt;</xsl:text><xsl:value-of select="@filename"/><xsl:text>&lt;/a&gt;</xsl:text>
          &lt;/li&gt;
      </xsl:for-each>
      &lt;/ul&gt;
    </xsl:for-each>

    <xsl:text>&lt;h1&gt;Test Cases&lt;/h1&gt;</xsl:text>
    <xsl:call-template name="newline"/>
    <xsl:for-each select="testcases/testcase">
      <xsl:text>&lt;h2&gt;Test Case:</xsl:text><xsl:value-of select="@title"/><xsl:text>&lt;/h2&gt;</xsl:text>
      <xsl:call-template name="newline"/>
      
      <xsl:text>&lt;b&gt;Pre-Condtions&lt;/b&gt;</xsl:text>
      &lt;ul&gt;
      <xsl:for-each select="preconditions/condition">
          &lt;li&gt;
            <xsl:value-of select="brief"/><xsl:text> - </xsl:text><xsl:value-of select="description"/>
          &lt;/li&gt;
      </xsl:for-each>
      &lt;/ul&gt;
      
      <xsl:text>&lt;b&gt;Post-Condtions&lt;/b&gt;</xsl:text>
      &lt;ul&gt;
      <xsl:for-each select="postconditions/condition">
          &lt;li&gt;
            <xsl:value-of select="brief"/><xsl:text> - </xsl:text><xsl:value-of select="description"/>
          &lt;/li&gt;
      </xsl:for-each>
      &lt;/ul&gt;
      
      <xsl:text>&lt;b&gt;Steps&lt;/b&gt;</xsl:text>
      &lt;ul&gt;
      <xsl:for-each select="steps/condition">
          &lt;li&gt;
            <xsl:value-of select="brief"/><xsl:text> - </xsl:text><xsl:value-of select="description"/>
          &lt;/li&gt;
      </xsl:for-each>
      &lt;/ul&gt;
    </xsl:for-each>
    <xsl:call-template name="newline"/>
    
    <xsl:call-template name="end_body"/>
  </xsl:template>

  <!-- Template methods -->
  <xsl:template name="begin_body">
    <xsl:text>
      &lt;html xmlns="http://www.w3.org/1999/xhtml"&gt;
        &lt;head&gt;
          &lt;title&gt;Nautica2.2 Liquid&lt;/title&gt;
          &lt;meta http-equiv="Content-Type" content="text/html; charset=utf-8" /&gt;
          &lt;link rel="stylesheet" type="text/css" href="styles/nautica/style.css" /&gt;
        &lt;/head&gt;
      &lt;body&gt;
      &lt;div id="wrapper-menu-top"&gt;
        &lt;div id="menu-top"&gt;
        	&lt;ul&gt;
        		&lt;li&gt;&lt;a href="#" title="Downloads"&gt;&lt;span&gt;Meetings&lt;/span&gt;&lt;/a&gt;&lt;/li&gt;
        		&lt;li&gt;&lt;a href="#" title="Gallery"&gt;&lt;span&gt;Requirements&lt;/span&gt;&lt;/a&gt;&lt;/li&gt;
        		&lt;li&gt;&lt;a href="#" title="Links"&gt;&lt;span&gt;Test Cases&lt;/span&gt;&lt;/a&gt;&lt;/li&gt;
        	&lt;/ul&gt;
        &lt;/div&gt;
      &lt;/div&gt;

      &lt;div id="wrapper-header"&gt;
        &lt;div id="header"&gt;
          &lt;div id="wrapper-header2"&gt;
            &lt;div id="wrapper-header3"&gt;
              &lt;h1&gt;SLIM - Software Life-cycle Management v1.0&lt;/h1&gt;
            &lt;/div&gt;
          &lt;/div&gt;
        &lt;/div&gt;
      &lt;/div&gt;

      &lt;div id="wrapper-content"&gt;
        &lt;div id="content"&gt;
          &lt;p&gt;

    </xsl:text>
  </xsl:template>

  <xsl:template name="end_body">
  
            &lt;/p&gt;
          &lt;/div&gt;
        &lt;/div&gt;

        &lt;div id="wrapper-footer"&gt;
          &lt;div id="footer"&gt;
            &lt;a href="http://www.taloncomputing.co.za"&gt;Talon Computing&lt;/a&gt;
          &lt;/div&gt;
        &lt;/div&gt;
      &lt;/body&gt;
    &lt;/html&gt;
  </xsl:template>
  
  <xsl:template name="newline">
    <xsl:text>&lt;br/&gt;</xsl:text>
  </xsl:template>

</xsl:stylesheet>